@@ -291,54 +291,6 @@ GType  bd_crypto_integrity_info_get_type () {
     return type;
 }
 
-static const gchar* const crypto_functions[] = {
-    "bd_crypto_is_tech_avail",
-    "bd_crypto_generate_backup_passphrase",
-    "bd_crypto_device_is_luks",
-    "bd_crypto_luks_uuid",
-    "bd_crypto_luks_get_metadata_size",
-    "bd_crypto_luks_status",
-    "bd_crypto_luks_format",
-    "bd_crypto_luks_format_blob",
-    "bd_crypto_luks_format_luks2",
-    "bd_crypto_luks_format_luks2_blob",
-    "bd_crypto_luks_open",
-    "bd_crypto_luks_open_blob",
-    "bd_crypto_luks_close",
-    "bd_crypto_luks_add_key",
-    "bd_crypto_luks_add_key_blob",
-    "bd_crypto_luks_remove_key",
-    "bd_crypto_luks_remove_key_blob",
-    "bd_crypto_luks_change_key",
-    "bd_crypto_luks_change_key_blob",
-    "bd_crypto_luks_resize",
-    "bd_crypto_luks_resize_luks2",
-    "bd_crypto_luks_resize_luks2_blob",
-    "bd_crypto_luks_suspend",
-    "bd_crypto_luks_resume_blob",
-    "bd_crypto_luks_resume",
-    "bd_crypto_luks_kill_slot",
-    "bd_crypto_luks_header_backup",
-    "bd_crypto_luks_header_restore",
-    "bd_crypto_luks_info",
-    "bd_crypto_integrity_info",
-    "bd_crypto_device_seems_encrypted",
-    "bd_crypto_tc_open",
-    "bd_crypto_tc_open_full",
-    "bd_crypto_tc_close",
-    "bd_crypto_escrow_device",
-    NULL};
-
-const gchar* const* get_crypto_functions (void) {
-    return crypto_functions;
-}
-
-static const guint8 crypto_num_functions = 35;
-
-guint8 get_crypto_num_functions (void) {
-    return crypto_num_functions;
-}
-
 static gboolean  bd_crypto_is_tech_avail_stub (BDCryptoTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_crypto_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
@@ -1310,7 +1262,7 @@ gboolean  bd_crypto_escrow_device (const gchar *device, const gchar *passphrase,
 }
 
 
-gpointer load_crypto_from_plugin(const gchar *so_name) {
+static gpointer load_crypto_from_plugin(const gchar *so_name) {
     void *handle = NULL;
     char *error = NULL;
     gboolean (*check_fn) (void) = NULL;
@@ -1326,19 +1278,23 @@ gpointer load_crypto_from_plugin(const gchar *so_name) {
     * (void**) (&check_fn) = dlsym(handle, "bd_crypto_check_deps");
     if ((error = dlerror()) != NULL)
         g_debug("failed to load the check() function for crypto: %s", error);
+    /* coverity[dead_error_condition] */
     if (!g_getenv ("LIBBLOCKDEV_SKIP_DEP_CHECKS") && check_fn && !check_fn()) {
         dlclose(handle);
         return NULL;
-    }    check_fn = NULL;
+    }
+    check_fn = NULL;
 
     dlerror();
     * (void**) (&init_fn) = dlsym(handle, "bd_crypto_init");
     if ((error = dlerror()) != NULL)
         g_debug("failed to load the init() function for crypto: %s", error);
+    /* coverity[dead_error_condition] */
     if (init_fn && !init_fn()) {
         dlclose(handle);
         return NULL;
-    }    init_fn = NULL;
+    }
+    init_fn = NULL;
 
     dlerror();
     * (void**) (&_bd_crypto_is_tech_avail) = dlsym(handle, "bd_crypto_is_tech_avail");
@@ -1518,7 +1474,7 @@ gpointer load_crypto_from_plugin(const gchar *so_name) {
     return handle;
 }
 
-gboolean unload_crypto (gpointer handle) {
+static gboolean unload_crypto (gpointer handle) {
     char *error = NULL;
     gboolean (*close_fn) (void) = NULL;
 
@@ -1562,6 +1518,7 @@ gboolean unload_crypto (gpointer handle) {
     * (void**) (&close_fn) = dlsym(handle, "bd_crypto_close");
     if (((error = dlerror()) != NULL) || !close_fn)
         g_debug("failed to load the close_plugin() function for crypto: %s", error);
+    /* coverity[dead_error_condition] */
     if (close_fn) {
         close_fn();
     }
