@@ -267,76 +267,6 @@ GType  bd_fs_ntfs_info_get_type () {
     return type;
 }
 
-static const gchar* const fs_functions[] = {
-    "bd_fs_is_tech_avail",
-    "bd_fs_wipe",
-    "bd_fs_clean",
-    "bd_fs_get_fstype",
-    "bd_fs_unmount",
-    "bd_fs_mount",
-    "bd_fs_get_mountpoint",
-    "bd_fs_resize",
-    "bd_fs_repair",
-    "bd_fs_check",
-    "bd_fs_set_label",
-    "bd_fs_can_resize",
-    "bd_fs_can_check",
-    "bd_fs_can_repair",
-    "bd_fs_can_set_label",
-    "bd_fs_ext2_mkfs",
-    "bd_fs_ext3_mkfs",
-    "bd_fs_ext4_mkfs",
-    "bd_fs_ext2_wipe",
-    "bd_fs_ext3_wipe",
-    "bd_fs_ext4_wipe",
-    "bd_fs_ext2_check",
-    "bd_fs_ext3_check",
-    "bd_fs_ext4_check",
-    "bd_fs_ext2_repair",
-    "bd_fs_ext3_repair",
-    "bd_fs_ext4_repair",
-    "bd_fs_ext2_set_label",
-    "bd_fs_ext3_set_label",
-    "bd_fs_ext4_set_label",
-    "bd_fs_ext2_get_info",
-    "bd_fs_ext3_get_info",
-    "bd_fs_ext4_get_info",
-    "bd_fs_ext2_resize",
-    "bd_fs_ext3_resize",
-    "bd_fs_ext4_resize",
-    "bd_fs_xfs_mkfs",
-    "bd_fs_xfs_wipe",
-    "bd_fs_xfs_check",
-    "bd_fs_xfs_repair",
-    "bd_fs_xfs_set_label",
-    "bd_fs_xfs_get_info",
-    "bd_fs_xfs_resize",
-    "bd_fs_vfat_mkfs",
-    "bd_fs_vfat_wipe",
-    "bd_fs_vfat_check",
-    "bd_fs_vfat_repair",
-    "bd_fs_vfat_set_label",
-    "bd_fs_vfat_get_info",
-    "bd_fs_vfat_resize",
-    "bd_fs_ntfs_mkfs",
-    "bd_fs_ntfs_wipe",
-    "bd_fs_ntfs_check",
-    "bd_fs_ntfs_repair",
-    "bd_fs_ntfs_set_label",
-    "bd_fs_ntfs_resize",
-    "bd_fs_ntfs_get_info",
-    NULL};
-
-const gchar* const* get_fs_functions (void) {
-    return fs_functions;
-}
-
-static const guint8 fs_num_functions = 57;
-
-guint8 get_fs_num_functions (void) {
-    return fs_num_functions;
-}
-
 static gboolean  bd_fs_is_tech_avail_stub (BDFSTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_fs_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
@@ -439,6 +369,56 @@ gchar* bd_fs_get_fstype (const gchar *device,  GError **error) {
 }
 
 
+static gboolean  bd_fs_freeze_stub (const gchar *mountpoint, GError **error) {
+    g_critical ("The function 'bd_fs_freeze' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_freeze' called, but not implemented!");
+    return FALSE;
+}
+
+static gboolean  (*_bd_fs_freeze) (const gchar *mountpoint, GError **error) = bd_fs_freeze_stub;
+
+/**
+ * bd_fs_freeze:
+ * @mountpoint: mountpoint of the device (filesystem) to freeze
+ * @error: (out): place to store error (if any)
+ *
+ * Freezes filesystem mounted on @mountpoint. The filesystem must
+ * support freezing.
+ *
+ * Returns: whether @mountpoint was successfully freezed or not
+ *
+ */
+gboolean  bd_fs_freeze (const gchar *mountpoint, GError **error) {
+    return _bd_fs_freeze (mountpoint, error);
+}
+
+
+static gboolean  bd_fs_unfreeze_stub (const gchar *mountpoint, GError **error) {
+    g_critical ("The function 'bd_fs_unfreeze' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_unfreeze' called, but not implemented!");
+    return FALSE;
+}
+
+static gboolean  (*_bd_fs_unfreeze) (const gchar *mountpoint, GError **error) = bd_fs_unfreeze_stub;
+
+/**
+ * bd_fs_unfreeze:
+ * @mountpoint: mountpoint of the device (filesystem) to un-freeze
+ * @error: (out): place to store error (if any)
+ *
+ * Un-freezes filesystem mounted on @mountpoint. The filesystem must
+ * support freezing.
+ *
+ * Returns: whether @mountpoint was successfully unfreezed or not
+ *
+ */
+gboolean  bd_fs_unfreeze (const gchar *mountpoint, GError **error) {
+    return _bd_fs_unfreeze (mountpoint, error);
+}
+
+
 static gboolean  bd_fs_unmount_stub (const gchar *spec, gboolean lazy, gboolean force, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_fs_unmount' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
@@ -530,6 +510,29 @@ gchar* bd_fs_get_mountpoint (const gchar *device, GError **error) {
 }
 
 
+static gboolean  bd_fs_is_mountpoint_stub (const gchar *path, GError **error) {
+    g_critical ("The function 'bd_fs_is_mountpoint' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_is_mountpoint' called, but not implemented!");
+    return FALSE;
+}
+
+static gboolean  (*_bd_fs_is_mountpoint) (const gchar *path, GError **error) = bd_fs_is_mountpoint_stub;
+
+/**
+ * bd_fs_is_mountpoint:
+ * @path: path (folder) to check
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether @path is a mountpoint or not
+ *
+ * Tech category: %BD_FS_TECH_MOUNT (no mode, ignored)
+ */
+gboolean  bd_fs_is_mountpoint (const gchar *path, GError **error) {
+    return _bd_fs_is_mountpoint (path, error);
+}
+
+
 static gboolean  bd_fs_resize_stub (const gchar *device, guint64 new_size, GError **error) {
     g_critical ("The function 'bd_fs_resize' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
@@ -1810,7 +1813,7 @@ BDFSNtfsInfo* bd_fs_ntfs_get_info (const gchar *device, GError **error) {
 }
 
 
-gpointer load_fs_from_plugin(const gchar *so_name) {
+static gpointer load_fs_from_plugin(const gchar *so_name) {
     void *handle = NULL;
     char *error = NULL;
     gboolean (*check_fn) (void) = NULL;
@@ -1826,19 +1829,23 @@ gpointer load_fs_from_plugin(const gchar *so_name) {
     * (void**) (&check_fn) = dlsym(handle, "bd_fs_check_deps");
     if ((error = dlerror()) != NULL)
         g_debug("failed to load the check() function for fs: %s", error);
+    /* coverity[dead_error_condition] */
     if (!g_getenv ("LIBBLOCKDEV_SKIP_DEP_CHECKS") && check_fn && !check_fn()) {
         dlclose(handle);
         return NULL;
-    }    check_fn = NULL;
+    }
+    check_fn = NULL;
 
     dlerror();
     * (void**) (&init_fn) = dlsym(handle, "bd_fs_init");
     if ((error = dlerror()) != NULL)
         g_debug("failed to load the init() function for fs: %s", error);
+    /* coverity[dead_error_condition] */
     if (init_fn && !init_fn()) {
         dlclose(handle);
         return NULL;
-    }    init_fn = NULL;
+    }
+    init_fn = NULL;
 
     dlerror();
     * (void**) (&_bd_fs_is_tech_avail) = dlsym(handle, "bd_fs_is_tech_avail");
@@ -1860,6 +1867,16 @@ gpointer load_fs_from_plugin(const gchar *so_name) {
     if ((error = dlerror()) != NULL)
         g_warning("failed to load bd_fs_get_fstype: %s", error);
 
+    dlerror();
+    * (void**) (&_bd_fs_freeze) = dlsym(handle, "bd_fs_freeze");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_freeze: %s", error);
+
+    dlerror();
+    * (void**) (&_bd_fs_unfreeze) = dlsym(handle, "bd_fs_unfreeze");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_unfreeze: %s", error);
+
     dlerror();
     * (void**) (&_bd_fs_unmount) = dlsym(handle, "bd_fs_unmount");
     if ((error = dlerror()) != NULL)
@@ -1875,6 +1892,11 @@ gpointer load_fs_from_plugin(const gchar *so_name) {
     if ((error = dlerror()) != NULL)
         g_warning("failed to load bd_fs_get_mountpoint: %s", error);
 
+    dlerror();
+    * (void**) (&_bd_fs_is_mountpoint) = dlsym(handle, "bd_fs_is_mountpoint");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_is_mountpoint: %s", error);
+
     dlerror();
     * (void**) (&_bd_fs_resize) = dlsym(handle, "bd_fs_resize");
     if ((error = dlerror()) != NULL)
@@ -2128,7 +2150,7 @@ gpointer load_fs_from_plugin(const gchar *so_name) {
     return handle;
 }
 
-gboolean unload_fs (gpointer handle) {
+static gboolean unload_fs (gpointer handle) {
     char *error = NULL;
     gboolean (*close_fn) (void) = NULL;
 
@@ -2136,9 +2158,12 @@ gboolean unload_fs (gpointer handle) {
     _bd_fs_wipe = bd_fs_wipe_stub;
     _bd_fs_clean = bd_fs_clean_stub;
     _bd_fs_get_fstype = bd_fs_get_fstype_stub;
+    _bd_fs_freeze = bd_fs_freeze_stub;
+    _bd_fs_unfreeze = bd_fs_unfreeze_stub;
     _bd_fs_unmount = bd_fs_unmount_stub;
     _bd_fs_mount = bd_fs_mount_stub;
     _bd_fs_get_mountpoint = bd_fs_get_mountpoint_stub;
+    _bd_fs_is_mountpoint = bd_fs_is_mountpoint_stub;
     _bd_fs_resize = bd_fs_resize_stub;
     _bd_fs_repair = bd_fs_repair_stub;
     _bd_fs_check = bd_fs_check_stub;
@@ -2194,6 +2219,7 @@ gboolean unload_fs (gpointer handle) {
     * (void**) (&close_fn) = dlsym(handle, "bd_fs_close");
     if (((error = dlerror()) != NULL) || !close_fn)
         g_debug("failed to load the close_plugin() function for fs: %s", error);
+    /* coverity[dead_error_condition] */
     if (close_fn) {
         close_fn();
     }
