@@ -278,6 +278,34 @@ gboolean  bd_fs_clean (const gchar *device, GError **error);
 gchar* bd_fs_get_fstype (const gchar *device,  GError **error);
 
 
+/**
+ * bd_fs_freeze:
+ * @mountpoint: mountpoint of the device (filesystem) to freeze
+ * @error: (out): place to store error (if any)
+ *
+ * Freezes filesystem mounted on @mountpoint. The filesystem must
+ * support freezing.
+ *
+ * Returns: whether @mountpoint was successfully freezed or not
+ *
+ */
+gboolean  bd_fs_freeze (const gchar *mountpoint, GError **error);
+
+
+/**
+ * bd_fs_unfreeze:
+ * @mountpoint: mountpoint of the device (filesystem) to un-freeze
+ * @error: (out): place to store error (if any)
+ *
+ * Un-freezes filesystem mounted on @mountpoint. The filesystem must
+ * support freezing.
+ *
+ * Returns: whether @mountpoint was successfully unfreezed or not
+ *
+ */
+gboolean  bd_fs_unfreeze (const gchar *mountpoint, GError **error);
+
+
 /**
  * bd_fs_unmount:
  * @spec: mount point or device to unmount
@@ -336,6 +364,18 @@ gboolean  bd_fs_mount (const gchar *device, const gchar *mountpoint, const gchar
 gchar* bd_fs_get_mountpoint (const gchar *device, GError **error);
 
 
+/**
+ * bd_fs_is_mountpoint:
+ * @path: path (folder) to check
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether @path is a mountpoint or not
+ *
+ * Tech category: %BD_FS_TECH_MOUNT (no mode, ignored)
+ */
+gboolean  bd_fs_is_mountpoint (const gchar *path, GError **error);
+
+
 /**
  * bd_fs_resize:
  * @device: the device the file system of which to resize
@@ -814,8 +854,8 @@ gboolean  bd_fs_xfs_wipe (const gchar *device, GError **error);
  *
  * Returns: whether an xfs file system on the @device is clean or not
  *
- * Note: if the file system is mounted it may be reported as unclean even if
- *       everything is okay and there are just some pending/in-progress writes
+ * Note: If the file system is mounted RW, it will always be reported as not
+ *       clean!
  *
  * Tech category: %BD_FS_TECH_XFS-%BD_FS_TECH_MODE_CHECK
  */
