@@ -1,3 +1,8 @@
+/**
+ * BD_LVM_MAX_LV_SIZE:
+ *
+ * Deprecated: 2.23: Use bd_lvm_get_max_lv_size() function instead.
+ */
 GQuark  bd_lvm_error_quark (void) {
         return g_quark_from_static_string ("g-bd-lvm-error-quark");
 }
@@ -272,75 +277,6 @@ GType  bd_lvm_cache_stats_get_type () {
     return type;
 }
 
-static const gchar* const lvm_functions[] = {
-    "bd_lvm_is_tech_avail",
-    "bd_lvm_is_supported_pe_size",
-    "bd_lvm_get_supported_pe_sizes",
-    "bd_lvm_get_max_lv_size",
-    "bd_lvm_round_size_to_pe",
-    "bd_lvm_get_lv_physical_size",
-    "bd_lvm_get_thpool_padding",
-    "bd_lvm_get_thpool_meta_size",
-    "bd_lvm_is_valid_thpool_md_size",
-    "bd_lvm_is_valid_thpool_chunk_size",
-    "bd_lvm_pvcreate",
-    "bd_lvm_pvresize",
-    "bd_lvm_pvremove",
-    "bd_lvm_pvmove",
-    "bd_lvm_pvscan",
-    "bd_lvm_pvinfo",
-    "bd_lvm_pvs",
-    "bd_lvm_vgcreate",
-    "bd_lvm_vgremove",
-    "bd_lvm_vgrename",
-    "bd_lvm_vgactivate",
-    "bd_lvm_vgdeactivate",
-    "bd_lvm_vgextend",
-    "bd_lvm_vgreduce",
-    "bd_lvm_vginfo",
-    "bd_lvm_vgs",
-    "bd_lvm_lvorigin",
-    "bd_lvm_lvcreate",
-    "bd_lvm_lvremove",
-    "bd_lvm_lvrename",
-    "bd_lvm_lvresize",
-    "bd_lvm_lvactivate",
-    "bd_lvm_lvdeactivate",
-    "bd_lvm_lvsnapshotcreate",
-    "bd_lvm_lvsnapshotmerge",
-    "bd_lvm_lvinfo",
-    "bd_lvm_lvs",
-    "bd_lvm_thpoolcreate",
-    "bd_lvm_thlvcreate",
-    "bd_lvm_thlvpoolname",
-    "bd_lvm_thsnapshotcreate",
-    "bd_lvm_set_global_config",
-    "bd_lvm_get_global_config",
-    "bd_lvm_cache_get_default_md_size",
-    "bd_lvm_cache_get_mode_str",
-    "bd_lvm_cache_get_mode_from_str",
-    "bd_lvm_cache_create_pool",
-    "bd_lvm_cache_attach",
-    "bd_lvm_cache_detach",
-    "bd_lvm_cache_create_cached_lv",
-    "bd_lvm_cache_pool_name",
-    "bd_lvm_cache_stats",
-    "bd_lvm_data_lv_name",
-    "bd_lvm_metadata_lv_name",
-    "bd_lvm_thpool_convert",
-    "bd_lvm_cache_pool_convert",
-    NULL};
-
-const gchar* const* get_lvm_functions (void) {
-    return lvm_functions;
-}
-
-static const guint8 lvm_num_functions = 56;
-
-guint8 get_lvm_num_functions (void) {
-    return lvm_num_functions;
-}
-
 static gboolean  bd_lvm_is_tech_avail_stub (BDLVMTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_lvm_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
@@ -1808,7 +1744,7 @@ gboolean  bd_lvm_cache_pool_convert (const gchar *vg_name, const gchar *data_lv,
 }
 
 
-gpointer load_lvm_from_plugin(const gchar *so_name) {
+static gpointer load_lvm_from_plugin(const gchar *so_name) {
     void *handle = NULL;
     char *error = NULL;
     gboolean (*check_fn) (void) = NULL;
@@ -1824,19 +1760,23 @@ gpointer load_lvm_from_plugin(const gchar *so_name) {
     * (void**) (&check_fn) = dlsym(handle, "bd_lvm_check_deps");
     if ((error = dlerror()) != NULL)
         g_debug("failed to load the check() function for lvm: %s", error);
+    /* coverity[dead_error_condition] */
     if (!g_getenv ("LIBBLOCKDEV_SKIP_DEP_CHECKS") && check_fn && !check_fn()) {
         dlclose(handle);
         return NULL;
-    }    check_fn = NULL;
+    }
+    check_fn = NULL;
 
     dlerror();
     * (void**) (&init_fn) = dlsym(handle, "bd_lvm_init");
     if ((error = dlerror()) != NULL)
         g_debug("failed to load the init() function for lvm: %s", error);
+    /* coverity[dead_error_condition] */
     if (init_fn && !init_fn()) {
         dlclose(handle);
         return NULL;
-    }    init_fn = NULL;
+    }
+    init_fn = NULL;
 
     dlerror();
     * (void**) (&_bd_lvm_is_tech_avail) = dlsym(handle, "bd_lvm_is_tech_avail");
@@ -2121,7 +2061,7 @@ gpointer load_lvm_from_plugin(const gchar *so_name) {
     return handle;
 }
 
-gboolean unload_lvm (gpointer handle) {
+static gboolean unload_lvm (gpointer handle) {
     char *error = NULL;
     gboolean (*close_fn) (void) = NULL;
 
@@ -2186,6 +2126,7 @@ gboolean unload_lvm (gpointer handle) {
     * (void**) (&close_fn) = dlsym(handle, "bd_lvm_close");
     if (((error = dlerror()) != NULL) || !close_fn)
         g_debug("failed to load the close_plugin() function for lvm: %s", error);
+    /* coverity[dead_error_condition] */
     if (close_fn) {
         close_fn();
     }
