@@ -6,13 +6,10 @@
 #ifndef BD_LVM_API
 #define BD_LVM_API
 
-#ifdef __LP64__
-// 64bit system
-#define BD_LVM_MAX_LV_SIZE (8 * 1152921504606846976ULL)
-#else
-// 32bit system
-#define BD_LVM_MAX_LV_SIZE (16 * 1099511627776ULL)
-#endif
+/* 8 EiB (valid only for 64bit devices but we can't have architecture
+   specific constant here) */
+#define BD_LVM_MAX_LV_SIZE G_GUINT64_CONSTANT (9223372036854775808ULL)
+
 
 #define BD_LVM_DEFAULT_PE_START (1 * 1048576ULL)
 #define BD_LVM_DEFAULT_PE_SIZE (4 * 1048576ULL)
@@ -27,6 +24,11 @@
 /* according to lvmcache (7) */
 #define BD_LVM_MIN_CACHE_MD_SIZE (8 * 1048576ULL)
 
+/**
+ * BD_LVM_MAX_LV_SIZE:
+ *
+ * Deprecated: 2.23: Use bd_lvm_get_max_lv_size() function instead.
+ */
 GQuark  bd_lvm_error_quark (void);
 
 
@@ -39,6 +41,7 @@ typedef enum {
     BD_LVM_ERROR_CACHE_INVAL,
     BD_LVM_ERROR_CACHE_NOCACHE,
     BD_LVM_ERROR_TECH_UNAVAIL,
+    BD_LVM_ERROR_FAIL,
 } BDLVMError;
 
 typedef enum {
