@@ -109,38 +109,6 @@ GType  bd_vdo_stats_get_type () {
     return type;
 }
 
-static const gchar* const vdo_functions[] = {
-    "bd_vdo_is_tech_avail",
-    "bd_vdo_get_write_policy_str",
-    "bd_vdo_get_write_policy_from_str",
-    "bd_vdo_info",
-    "bd_vdo_create",
-    "bd_vdo_remove",
-    "bd_vdo_change_write_policy",
-    "bd_vdo_enable_compression",
-    "bd_vdo_disable_compression",
-    "bd_vdo_enable_deduplication",
-    "bd_vdo_disable_deduplication",
-    "bd_vdo_activate",
-    "bd_vdo_deactivate",
-    "bd_vdo_start",
-    "bd_vdo_stop",
-    "bd_vdo_grow_logical",
-    "bd_vdo_grow_physical",
-    "bd_vdo_get_stats",
-    "bd_vdo_get_stats_full",
-    NULL};
-
-const gchar* const* get_vdo_functions (void) {
-    return vdo_functions;
-}
-
-static const guint8 vdo_num_functions = 19;
-
-guint8 get_vdo_num_functions (void) {
-    return vdo_num_functions;
-}
-
 static gboolean  bd_vdo_is_tech_avail_stub (BDVDOTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_vdo_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
@@ -636,7 +604,7 @@ GHashTable* bd_vdo_get_stats_full (const gchar *name, GError **error) {
 }
 
 
-gpointer load_vdo_from_plugin(const gchar *so_name) {
+static gpointer load_vdo_from_plugin(const gchar *so_name) {
     void *handle = NULL;
     char *error = NULL;
     gboolean (*check_fn) (void) = NULL;
@@ -652,19 +620,23 @@ gpointer load_vdo_from_plugin(const gchar *so_name) {
     * (void**) (&check_fn) = dlsym(handle, "bd_vdo_check_deps");
     if ((error = dlerror()) != NULL)
         g_debug("failed to load the check() function for vdo: %s", error);
+    /* coverity[dead_error_condition] */
     if (!g_getenv ("LIBBLOCKDEV_SKIP_DEP_CHECKS") && check_fn && !check_fn()) {
         dlclose(handle);
         return NULL;
-    }    check_fn = NULL;
+    }
+    check_fn = NULL;
 
     dlerror();
     * (void**) (&init_fn) = dlsym(handle, "bd_vdo_init");
     if ((error = dlerror()) != NULL)
         g_debug("failed to load the init() function for vdo: %s", error);
+    /* coverity[dead_error_condition] */
     if (init_fn && !init_fn()) {
         dlclose(handle);
         return NULL;
-    }    init_fn = NULL;
+    }
+    init_fn = NULL;
 
     dlerror();
     * (void**) (&_bd_vdo_is_tech_avail) = dlsym(handle, "bd_vdo_is_tech_avail");
@@ -764,7 +736,7 @@ gpointer load_vdo_from_plugin(const gchar *so_name) {
     return handle;
 }
 
-gboolean unload_vdo (gpointer handle) {
+static gboolean unload_vdo (gpointer handle) {
     char *error = NULL;
     gboolean (*close_fn) (void) = NULL;
 
@@ -792,6 +764,7 @@ gboolean unload_vdo (gpointer handle) {
     * (void**) (&close_fn) = dlsym(handle, "bd_vdo_close");
     if (((error = dlerror()) != NULL) || !close_fn)
         g_debug("failed to load the close_plugin() function for vdo: %s", error);
+    /* coverity[dead_error_condition] */
     if (close_fn) {
         close_fn();
     }
